@@ -7,8 +7,8 @@ from bitmapist import setup_redis, delete_all_events, mark_event,\
 
 
 def setup_module():
-    setup_redis('default', 'localhost', 6380)
-    setup_redis('default_copy', 'localhost', 6380)
+    setup_redis('default', 'localhost', 6399)
+    setup_redis('default_copy', 'localhost', 6399)
 
 
 def test_mark_with_diff_days():
@@ -49,6 +49,21 @@ def test_mark_counts():
     assert len(MonthEvents('active', now.year, now.month)) == 2
 
 
+def test_mark_iter():
+    delete_all_events()
+    now = datetime.utcnow()
+    ev = MonthEvents('active', now.year, now.month)
+
+    assert list(ev) == []
+
+    mark_event('active', 5)
+    mark_event('active', 55)
+    mark_event('active', 555)
+    mark_event('active', 5555)
+
+    assert list(ev) == [5, 55, 555, 5555]
+
+
 def test_different_dates():
     delete_all_events()
 
@@ -106,6 +121,7 @@ def test_bit_operations():
     assert active_2_months.get_count() == 1
     assert 123 in active_2_months
     assert 224 not in active_2_months
+    active_2_months.delete()
 
     # Try out with bit OR operation
     assert BitOpOr(
@@ -121,6 +137,7 @@ def test_bit_operations():
     )
     assert active_2_months.get_count() == 1
     assert active_2_months.system == 'default_copy'
+    active_2_months.delete()
 
     # Try nested operations
     active_2_months = BitOpAnd(
@@ -133,6 +150,7 @@ def test_bit_operations():
 
     assert 123 in active_2_months
     assert 224 not in active_2_months
+    active_2_months.delete()
 
 
 def test_events_marked():
